@@ -1,336 +1,342 @@
 package Statistics::Distribution::Generator;
 
-use 5.018;
+use 5.010;
 
 use overload (
-    '0+' => '_render',
-    '""' => '_render',
-    '@{}' => '_render',
-    '|' => '_add_alternative',
-    'x' => '_add_dimension',
-    fallback => 1,
+  '0+' => '_render',
+  '""' => '_render',
+  '@{}' => '_render',
+  '|' => '_add_alternative',
+  'x' => '_add_dimension',
+  fallback => 1,
 );
 
 use List::AllUtils qw( reduce );
 use Exporter qw( import );
 use vars qw( $VERSION );
 
-$VERSION = '1.000';
+$VERSION = '1.001';
 
 sub logistic ();
 
 our @EXPORT_OK = qw( gaussian uniform logistic supplied gamma exponential dice );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $pi = 3.14159265358979323846264338327950288419716939937510;
+our $pi = 3.1415926535897932384626433832795028841971693993751;
 our $two_pi = 2 * $pi;
 our $e = exp 1;
 
 sub _render {
-    my $self = shift;
-    if ($self->{ dims }) {
-        return [ map { $_->_render } @{$self->{ dims }} ];
-    }
-    elsif ($self->{ alts }) {
-        my $accum = reduce { $a + $b } map { $_->{ weight } // 1 } @{$self->{ alts }};
-        my $n = rand() * $accum;
-        my $answer;
-        for my $alt (@{$self->{ alts }}) {
-            $n -= ($alt->{ weight } // 1);
-            if ($n <= 0) {
-                $answer = $alt->_render;
-                last;
-            }
-        }
-        return $answer;
-    }
-    else {
-        die "Something horrible has happened";
+  my $self = shift;
+  if ($self->{ dims }) {
+    return [ map { $_->_render } @{$self->{ dims }} ];
+  }
+  elsif ($self->{ alts }) {
+    my $accum = reduce { $a + $b } map { $_->{ weight } // 1 } @{$self->{ alts }};
+    my $n = rand() * $accum;
+    my $answer;
+    for my $alt (@{$self->{ alts }}) {
+      $n -= ($alt->{ weight } // 1);
+      if ($n <= 0) {
+        $answer = $alt->_render;
+        last;
+      }
     }
+    return $answer;
+  }
+  die("Can't render a(n) " . (ref($self)||$self));
 }
 
 sub gaussian {
-    my ($mean, $sigma) = @_;
-    $mean //= 0;
-    $sigma //= 1;
-    return bless { mean => $mean, sigma => $sigma }, 'Statistics::Distribution::Generator::gaussian';
+  my ($mean, $sigma) = @_;
+  $mean //= 0;
+  $sigma //= 1;
+  return bless { mean => $mean, sigma => $sigma }, 'Statistics::Distribution::Generator::gaussian';
 }
 
 sub uniform {
-    my ($min, $max) = @_;
-    $min //= 0;
-    $max //= 1;
-    return bless { min => $min, max => $max }, 'Statistics::Distribution::Generator::uniform';
+  my ($min, $max) = @_;
+  $min //= 0;
+  $max //= 1;
+  return bless { min => $min, max => $max }, 'Statistics::Distribution::Generator::uniform';
 }
 
 sub logistic () {
-    return bless { }, 'Statistics::Distribution::Generator::logistic';
+  return bless { }, 'Statistics::Distribution::Generator::logistic';
 }
 
 sub supplied {
-    my ($iv) = @_;
-    my $rv;
-    if (ref $iv eq 'CODE') {
-        $rv = { code => $iv };
-    }
-    else {
-        $rv = { code => sub { return $iv } };
-    }
-    return bless $rv, 'Statistics::Distribution::Generator::supplied';
+  my ($iv) = @_;
+  my $rv;
+  if (ref $iv eq 'CODE') {
+    $rv = { code => $iv };
+  }
+  else {
+    $rv = { code => sub { return $iv } };
+  }
+  return bless $rv, 'Statistics::Distribution::Generator::supplied';
 }
 
 sub gamma {
-    my ($order, $scale) = map { $_ // 1 } @_;
-    return bless {
-        order => $order,
-        scale => $scale,
-        norder => int($order),
-    }, 'Statistics::Distribution::Generator::gamma';
+  my ($order, $scale) = map { $_ // 1 } @_;
+  return bless {
+    order => $order,
+    scale => $scale,
+    norder => int($order),
+  }, 'Statistics::Distribution::Generator::gamma';
 }
 
 sub exponential {
-    my ($lambda) = map { $_ // 1 } @_;
-    return bless { lambda => $lambda }, 'Statistics::Distribution::Generator::exponential';
+  my ($lambda) = map { $_ // 1 } @_;
+  return bless { lambda => $lambda }, 'Statistics::Distribution::Generator::exponential';
 }
 
 sub dice {
-    my ($numdice, $numsides) = @_;
-    return bless {
-        numdice => $numdice,
-        numsides => $numsides,
-    } => 'Statistics::Distribution::Generator::dice';
+  my ($numdice, $numsides) = @_;
+  return bless {
+    numdice => $numdice,
+    numsides => $numsides,
+  } => 'Statistics::Distribution::Generator::dice';
 }
 
 sub _rand_nonzero {
-    my $rv;
-    1 while (!($rv = rand));
-    return $rv;
-}
-
-sub _gamma_int {
-    my $order = shift;
-    if ($order < 12){
-        my $prod = 1;
-        for (my $i=0; $i<$order; $i++){
-            $prod *= _rand_nonzero();
-        }
-        return -log($prod);
-    }
-    else {
-        return _gamma_large_int($order);
-    }
-}
-
-sub _tan { sin($_[0]) / cos($_[0]); }
-
-sub _gamma_large_int {
-    my $order = shift;
-    my $sqrt = sqrt(2 * $order - 1);
-    my ($x,$y,$v);
-    do {
-        do {
-            $y = _tan($pi * rand);
-            $x = $sqrt * $y + $order - 1;
-        } while ($x <= 0);
-        $v = rand;
-    } while ($v > (1 + $y * $y) * exp(($order - 1) * log($x / ($order - 1)) - $sqrt * $y));
-    return $x;
-}
-
-sub _gamma_frac {
-    my $order = shift;
-    my $p = $e / ($order + $e);
-    my ($q, $x, $u, $v);
-    do {
-        $u = rand;
-        $v = _rand_nonzero();
-        if ($u < $p){
-            $x = exp((1 / $order) * log($v));
-            $q = exp(-$x);
-        }
-        else {
-            $x = 1 - log($v);
-            $q = exp(($order - 1) * log($x));
-        }
-    } while (rand >= $q);
-    return $x;
+  my $rv;
+  1 while (!($rv = rand));
+  return $rv;
 }
 
 sub _add_alternative {
-    my ($lhs, $rhs, $swapped) = @_;
-    ($lhs, $rhs) = ($rhs, $lhs) if $swapped;
-    $rhs = supplied($rhs) unless ref($rhs) =~ /^Statistics::Distribution::Generator/;
-    my $self
-        = ref($lhs) eq 'Statistics::Distribution::Generator'
-        ? { alts => [ ], %$lhs }
-        : { alts => [ $lhs ] }
-        ;
-    bless $self, 'Statistics::Distribution::Generator';
-    push @{$self->{ alts }}, $rhs;
-    return $self;
+  my ($lhs, $rhs, $swapped) = @_;
+  ($lhs, $rhs) = ($rhs, $lhs) if $swapped;
+  $rhs = supplied($rhs) unless ref($rhs) =~ /^Statistics::Distribution::Generator/;
+  if (!exists($lhs->{ alts })) {
+    $lhs = {
+      alts => [ $lhs ],
+    };
+  }
+  if (!exists($rhs->{ alts })) {
+    $rhs = {
+      alts => [ $rhs ],
+    };
+  }
+  push @{$lhs->{ alts }}, @{$rhs->{ alts }};
+  return bless $lhs, 'Statistics::Distribution::Generator';
 }
 
 sub _add_dimension {
-    my ($lhs, $rhs, $swapped) = @_;
-    ($lhs, $rhs) = ($rhs, $lhs) if $swapped;
-    $rhs = supplied($rhs) unless ref($rhs) =~ /^Statistics::Distribution::Generator/;
-    my $self
-        = ref($lhs) eq 'Statistics::Distribution::Generator'
-        ? { dims => [ ], %$lhs }
-        : { dims => [ $lhs ] }
-        ;
-    bless $self, 'Statistics::Distribution::Generator';
-    push @{$self->{ dims }}, $rhs;
-    return $self;
+  my ($lhs, $rhs, $swapped) = @_;
+  ($lhs, $rhs) = ($rhs, $lhs) if $swapped;
+  $rhs = supplied($rhs) unless ref($rhs) =~ /^Statistics::Distribution::Generator/;
+  if (!exists($lhs->{ dims })) {
+    $lhs = {
+      dims => [ $lhs ],
+    };
+  }
+  if (!exists($rhs->{ dims })) {
+    $rhs = {
+      dims => [ $rhs ],
+    };
+  }
+  push @{$lhs->{ dims }}, @{$rhs->{ dims }};
+  return bless $lhs, 'Statistics::Distribution::Generator';
 }
 
 1;
 
 package Statistics::Distribution::Generator::gaussian;
 
-use 5.018;
+use 5.010;
 use base qw( Statistics::Distribution::Generator );
 use overload (
-    '0+' => '_render',
-    '""' => '_render',
-    '|' => '_add_alternative',
-    'x' => '_add_dimension',
-    fallback => 1,
+  '0+' => '_render',
+  '""' => '_render',
+  '|' => '_add_alternative',
+  'x' => '_add_dimension',
+  fallback => 1,
 );
 
 sub _render {
-    my $self = shift;
-    my $U = rand;
-    my $V = rand;
-    return $self->{ mean } + (sqrt(-2 * log $U) * cos($two_pi * $V) * $self->{ sigma });
+  my $self = shift;
+  my $U = rand;
+  my $V = rand;
+  return $self->{ mean } + (sqrt(-2 * log $U) * cos($two_pi * $V) * $self->{ sigma });
 }
 
 1;
 
 package Statistics::Distribution::Generator::uniform;
 
-use 5.018;
+use 5.010;
 use base qw( Statistics::Distribution::Generator );
 use overload (
-    '0+' => '_render',
-    '""' => '_render',
-    '|' => '_add_alternative',
-    'x' => '_add_dimension',
-    fallback => 1,
+  '0+' => '_render',
+  '""' => '_render',
+  '|' => '_add_alternative',
+  'x' => '_add_dimension',
+  fallback => 1,
 );
 
 sub _render {
-    my $self = shift;
-    return ($self->{ max } - $self->{ min }) * rand() + $self->{ min };
+  my $self = shift;
+  return ($self->{ max } - $self->{ min }) * rand() + $self->{ min };
 }
 
 1;
 
 package Statistics::Distribution::Generator::logistic;
 
-use 5.018;
+use 5.010;
 use base qw( Statistics::Distribution::Generator );
 use overload (
-    '0+' => '_render',
-    '""' => '_render',
-    '|' => '_add_alternative',
-    'x' => '_add_dimension',
-    fallback => 1,
+  '0+' => '_render',
+  '""' => '_render',
+  '|' => '_add_alternative',
+  'x' => '_add_dimension',
+  fallback => 1,
 );
 
 sub _render {
-    my $self = shift;
-    return -log((1 / _rand_nonzero()) - 1);
+  my $self = shift;
+  return -log((1 / _rand_nonzero()) - 1);
 }
 
 1;
 
 package Statistics::Distribution::Generator::supplied;
 
-use 5.018;
+use 5.010;
 use base qw( Statistics::Distribution::Generator );
 use overload (
-    '0+' => '_render',
-    '""' => '_render',
-    '|' => '_add_alternative',
-    'x' => '_add_dimension',
-    fallback => 1,
+  '0+' => '_render',
+  '""' => '_render',
+  '|' => '_add_alternative',
+  'x' => '_add_dimension',
+  fallback => 1,
 );
 
 sub _render {
-    my $self = shift;
-    return $self->{ code }->();
+  my $self = shift;
+  return $self->{ code }->();
 }
 
 1;
 
 package Statistics::Distribution::Generator::gamma;
 
-use 5.018;
+use 5.010;
 use base qw( Statistics::Distribution::Generator );
 use overload (
-    '0+' => '_render',
-    '""' => '_render',
-    '|' => '_add_alternative',
-    'x' => '_add_dimension',
-    fallback => 1,
+  '0+' => '_render',
+  '""' => '_render',
+  '|' => '_add_alternative',
+  'x' => '_add_dimension',
+  fallback => 1,
 );
 
-sub _render {
-    my $self = shift;
-    my $rv;
-    if ($self->{ order } == $self->{ norder }) {
-        $rv = $self->{ scale } * _gamma_int($self->{ norder });
+sub _gamma_int {
+  my $order = shift;
+  if ($order < 12){
+    my $prod = 1;
+    for (my $i=0; $i<$order; $i++){
+      $prod *= _rand_nonzero();
     }
-    elsif ($self->{ norder } == 0) {
-        $rv = $self->{ scale } * _gamma_frac($self->{ order });
+    return -log($prod);
+  }
+  else {
+    return _gamma_large_int($order);
+  }
+}
+
+sub _tan { sin($_[0]) / cos($_[0]); }
+
+sub _gamma_large_int {
+  my $order = shift;
+  my $sqrt = sqrt(2 * $order - 1);
+  my ($x,$y,$v);
+  do {
+    do {
+      $y = _tan($pi * rand);
+      $x = $sqrt * $y + $order - 1;
+    } while ($x <= 0);
+    $v = rand;
+  } while ($v > (1 + $y * $y) * exp(($order - 1) * log($x / ($order - 1)) - $sqrt * $y));
+  return $x;
+}
+
+sub _gamma_frac {
+  my $order = shift;
+  my $p = $e / ($order + $e);
+  my ($q, $x, $u, $v);
+  do {
+    $u = rand;
+    $v = _rand_nonzero();
+    if ($u < $p){
+      $x = exp((1 / $order) * log($v));
+      $q = exp(-$x);
     }
     else {
-        $rv = $self->{ scale } * (_gamma_int($self->{ norder }) + _gamma_frac($self->{ norder } - $self->{ order }));
+      $x = 1 - log($v);
+      $q = exp(($order - 1) * log($x));
     }
-    return $rv;
+  } while (rand >= $q);
+  return $x;
+}
+
+sub _render {
+  my $self = shift;
+  my $rv;
+  if ($self->{ order } == $self->{ norder }) {
+    $rv = $self->{ scale } * _gamma_int($self->{ norder });
+  }
+  elsif ($self->{ norder } == 0) {
+    $rv = $self->{ scale } * _gamma_frac($self->{ order });
+  }
+  else {
+    $rv = $self->{ scale } * (_gamma_int($self->{ norder }) + _gamma_frac($self->{ norder } - $self->{ order }));
+  }
+  return $rv;
 }
 
 1;
 
 package Statistics::Distribution::Generator::exponential;
 
-use 5.018;
+use 5.010;
 use base qw( Statistics::Distribution::Generator );
 use overload (
-    '0+' => '_render',
-    '""' => '_render',
-    '|' => '_add_alternative',
-    'x' => '_add_dimension',
-    fallback => 1,
+  '0+' => '_render',
+  '""' => '_render',
+  '|' => '_add_alternative',
+  'x' => '_add_dimension',
+  fallback => 1,
 );
 
 sub _render {
-    my $self = shift;
-    my $rv = -log(rand) / $self->{ lambda };
+  my $self = shift;
+  my $rv = -log(rand) / $self->{ lambda };
 }
 
 1;
 
 package Statistics::Distribution::Generator::dice;
 
-use 5.018;
+use 5.010;
 use base qw( Statistics::Distribution::Generator );
 use overload (
-    '0+' => '_render',
-    '""' => '_render',
-    '|' => '_add_alternative',
-    'x' => '_add_dimension',
-    fallback => 1,
+  '0+' => '_render',
+  '""' => '_render',
+  '|' => '_add_alternative',
+  'x' => '_add_dimension',
+  fallback => 1,
 );
 
 sub _render {
-    my $self = shift;
-    my $rv;
-    for (1 .. $self->{ numdice }) {
-        $rv += int(1 + rand($self->{ numsides }));
-    }
-    return $rv;
+  my $self = shift;
+  my $rv;
+  for (1 .. $self->{ numdice }) {
+    $rv += int(1 + rand($self->{ numsides }));
+  }
+  return $rv;
 }
 
 1;
@@ -344,16 +350,16 @@ functions
 
 =head1 VERSION
 
-Version 1.000
+Version 1.001
 
 =head1 SYNOPSIS
 
-    use Statistics::Distribution::Generator qw( :all );
-    my $g = gaussian(3, 1);
-    say $g; # something almost certainly between -3 and 9, but probably about 2 .. 4-ish
-    my $cloud = gaussian(0, 1) x gaussian(0, 1) x gaussian(0, 1);
-    say @$cloud; # a 3D vector almost certainly within (+/- 6, +/- 6, +/- 6) and probably within (+/- 2, +/- 2, +/- 2)
-    my $combo = gaussian(100, 15) | uniform(0, 200); # one answer with an equal chance of being picked from either distribution
+  use Statistics::Distribution::Generator qw( :all );
+  my $g = gaussian(3, 1);
+  say $g; # something almost certainly between -3 and 9, but probably about 2 .. 4-ish
+  my $cloud = gaussian(0, 1) x gaussian(0, 1) x gaussian(0, 1);
+  say @$cloud; # a 3D vector almost certainly within (+/- 6, +/- 6, +/- 6) and probably within (+/- 2, +/- 2, +/- 2)
+  my $combo = gaussian(100, 15) | uniform(0, 200); # one answer with an equal chance of being picked from either distribution
 
 =head1 DESCRIPTION
 
@@ -389,14 +395,14 @@ many levels deep (within the usual memory & CPU limits of your computer, of
 course). You could, for instance, compose multiple "vectors" of different sizes
 using B<x> to form each one, and select between them at random with X<|>, e.g.
 
-    my $forwards = gaussian(0, 0.5) x gaussian(3, 1) x gaussian(0, 0.5);
-    my $backwards = gaussian(0, 0.5) x gaussian(-3, 1) x gaussian(0, 0.5);
-    my $left = gaussian(-3, 1) x gaussian(0, 0.5) x gaussian(0, 0.5);
-    my $right = gaussian(3, 1) x gaussian(0, 0.5) x gaussian(0, 0.5);
-    my $up = gaussian(0, 0.5) x gaussian(0, 0.5) x gaussian(3, 1);
-    my $down = gaussian(0, 0.5) x gaussian(0, 0.5) x gaussian(-3, 1);
-    my $direction = $forwards | $backwards | $left | $right | $up | $down;
-    $robot->move(@$direction);
+  my $forwards = gaussian(0, 0.5) x gaussian(3, 1) x gaussian(0, 0.5);
+  my $backwards = gaussian(0, 0.5) x gaussian(-3, 1) x gaussian(0, 0.5);
+  my $left = gaussian(-3, 1) x gaussian(0, 0.5) x gaussian(0, 0.5);
+  my $right = gaussian(3, 1) x gaussian(0, 0.5) x gaussian(0, 0.5);
+  my $up = gaussian(0, 0.5) x gaussian(0, 0.5) x gaussian(3, 1);
+  my $down = gaussian(0, 0.5) x gaussian(0, 0.5) x gaussian(-3, 1);
+  my $direction = $forwards | $backwards | $left | $right | $up | $down;
+  $robot->move(@$direction);
 
 You are strongly encouraged to seek further elucidation at Wikipedia or any
 other available reference site / material.
@@ -461,8 +467,8 @@ on your own in how to interpret that, and you are I<probably> doing it wrongly.
 The Gamma Distribution function is a generalization of the chi-squared and
 exponential distributions, and may be given by
 
-    p(x) dx = {1 \over \Gamma(a) b^a} x^{a-1} e^{-x/b} dx
-    for x > 0.
+  p(x) dx = {1 \over \Gamma(a) b^a} x^{a-1} e^{-x/b} dx
+  for x > 0.
 
 The ORDER argument corresponds to what is also known as the "shape parameter"
 I<k>, and the SCALE argument corresponds to the "scale parameter" I<theta>.
@@ -499,7 +505,7 @@ with I<SIDES> sides (numbered sequentially starting at 1), and summing the resul
 
 Allows you to compose multi-dimensional random vectors.
 
-    $randvect = $foo x $bar x $baz; # generate a three-dimensional vector
+  $randvect = $foo x $bar x $baz; # generate a three-dimensional vector
 
 =back
 
@@ -510,7 +516,7 @@ Allows you to compose multi-dimensional random vectors.
 Allows you to pick a single (optionally weighted) generator from some set of
 generators.
 
-    $cointoss = supplied 0 | supplied 1; # fair 50:50 result of either 0 or 1
+  $cointoss = supplied 0 | supplied 1; # fair 50:50 result of either 0 or 1
 
 =back
 
@@ -525,10 +531,10 @@ outcomes more (or less) than the remaining outcomes. The default weight for all
 outcomes is 1. Weights are relative, not absolute, so may be scaled however you
 need.
 
-    $foo = exponential 1.5;
-    $bar = gaussian 20, 1.25;
-    $foo->{ weight } = 6;
-    $quux = $foo | $bar; # 6:1 chance of picking $foo instead of $bar
+  $foo = exponential 1.5;
+  $bar = gaussian 20, 1.25;
+  $foo->{ weight } = 6;
+  $quux = $foo | $bar; # 6:1 chance of picking $foo instead of $bar
 
 =back
 
@@ -540,7 +546,7 @@ The idea of composing probabilities together is inspired by work done by Sooraj
 Bhat, Ashish Agarwal, Richard Vuduc, and Alexander Gray at Georgia Tech and
 NYU, published around the end of 2011.
 
-The implementation of the Gamma Distribution is by L<NWETTERS>.
+The implementation of the Gamma Distribution is by L<NWETTERS|https://metacpan.org/author/NWETTERS> and is used with permission.
 
 =head1 CAVEATS
 
@@ -580,10 +586,6 @@ and more use of L<Statistics::Descriptive>.
 
 Enhance the C<dice()> distribution to take the same args as L<Acme::Dice>?
 
-=item Older Perls?
-
-Why do we need 5.018? Investigate.
-
 =back
 
 =head1 LICENSE
